@@ -55,8 +55,9 @@ import time
 import sys
 import requests
 import jwt
+import urllib3
 
-from .Requester import Requester, json
+from .Requester import Requester
 from . import AuthenticatedUser
 from . import NamedUser
 from . import Organization
@@ -70,8 +71,6 @@ from . import Topic
 import github.GithubObject
 from . import HookDescription
 from . import GitignoreTemplate
-from . import Status
-from . import StatusMessage
 from . import RateLimit
 from . import InstallationAuthorization
 from . import GithubException
@@ -95,7 +94,7 @@ class Github(object):
     This is the main class you instantiate to access the Github API v3. Optional parameters allow different authentication methods.
     """
 
-    def __init__(self, login_or_token=None, password=None, jwt=None, base_url=DEFAULT_BASE_URL, timeout=DEFAULT_TIMEOUT, client_id=None, client_secret=None, user_agent='PyGithub/Python', per_page=DEFAULT_PER_PAGE, api_preview=False, verify=True):
+    def __init__(self, login_or_token=None, password=None, jwt=None, base_url=DEFAULT_BASE_URL, timeout=DEFAULT_TIMEOUT, client_id=None, client_secret=None, user_agent='PyGithub/Python', per_page=DEFAULT_PER_PAGE, api_preview=False, verify=True, retry=None):
         """
         :param login_or_token: string
         :param password: string
@@ -106,6 +105,7 @@ class Github(object):
         :param user_agent: string
         :param per_page: int
         :param verify: boolean or string
+        :param retry: int or urllib3.util.retry.Retry object
         """
 
         assert login_or_token is None or isinstance(login_or_token, str), login_or_token
@@ -117,7 +117,8 @@ class Github(object):
         assert client_secret is None or isinstance(client_secret, str), client_secret
         assert user_agent is None or isinstance(user_agent, str), user_agent
         assert isinstance(api_preview, (bool))
-        self.__requester = Requester(login_or_token, password, jwt, base_url, timeout, client_id, client_secret, user_agent, per_page, api_preview, verify)
+        assert retry is None or isinstance(retry, (int)) or isinstance(retry, (urllib3.util.Retry))
+        self.__requester = Requester(login_or_token, password, jwt, base_url, timeout, client_id, client_secret, user_agent, per_page, api_preview, verify, retry)
 
     def __get_FIX_REPO_GET_GIT_REF(self):
         """
@@ -681,45 +682,6 @@ class Github(object):
         """
         return self.create_from_raw_data(*pickle.load(f))
 
-    def get_api_status(self):
-        """
-        This doesn't work with a Github Enterprise installation, because it always targets https://status.github.com.
-
-        :calls: `GET /api/status.json <https://status.github.com/api>`_
-        :rtype: :class:`github.Status.Status`
-        """
-        headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET",
-            DEFAULT_STATUS_URL + "/api/status.json"
-        )
-        return Status.Status(self.__requester, headers, attributes, completed=True)
-
-    def get_last_api_status_message(self):
-        """
-        This doesn't work with a Github Enterprise installation, because it always targets https://status.github.com.
-
-        :calls: `GET /api/last-message.json <https://status.github.com/api>`_
-        :rtype: :class:`github.StatusMessage.StatusMessage`
-        """
-        headers, attributes = self.__requester.requestJsonAndCheck(
-            "GET",
-            DEFAULT_STATUS_URL + "/api/last-message.json"
-        )
-        return StatusMessage.StatusMessage(self.__requester, headers, attributes, completed=True)
-
-    def get_api_status_messages(self):
-        """
-        This doesn't work with a Github Enterprise installation, because it always targets https://status.github.com.
-
-        :calls: `GET /api/messages.json <https://status.github.com/api>`_
-        :rtype: list of :class:`github.StatusMessage.StatusMessage`
-        """
-        headers, data = self.__requester.requestJsonAndCheck(
-            "GET",
-            DEFAULT_STATUS_URL + "/api/messages.json"
-        )
-        return [StatusMessage.StatusMessage(self.__requester, headers, attributes, completed=True) for attributes in data]
-
     def get_installation(self, id):
         """
 
@@ -742,15 +704,18 @@ class GithubIntegration(object):
         self.integration_id = integration_id
         self.private_key = private_key
 
-    def create_jwt(self):
+    def create_jwt(self, expiration=60):
         """
-        Creates a signed JWT, valid for 60 seconds.
+        Creates a signed JWT, valid for 60 seconds by default.
+        The expiration can be extended beyond this, to a maximum of 600 seconds.
+
+        :param expiration: int
         :return:
         """
         now = int(time.time())
         payload = {
             "iat": now,
-            "exp": now + 60,
+            "exp": now + expiration,
             "iss": self.integration_id
         }
         encrypted = jwt.encode(
@@ -784,30 +749,25 @@ class GithubIntegration(object):
             },
             json=body
         )
-        response_text = response.text
-
-        if atLeastPython3:
-            response_text = response_text.decode('utf-8')
 
         if response.status_code == 201:
-            data = json.loads(response_text)
             return InstallationAuthorization.InstallationAuthorization(
                 requester=None,  # not required, this is a NonCompletableGithubObject
                 headers={},  # not required, this is a NonCompletableGithubObject
-                attributes=data,
+                attributes=response.json(),
                 completed=True
             )
         elif response.status_code == 403:
             raise GithubException.BadCredentialsException(
                 status=response.status_code,
-                data=response_text
+                data=response.text
             )
         elif response.status_code == 404:
             raise GithubException.UnknownObjectException(
                 status=response.status_code,
-                data=response_text
+                data=response.text
             )
         raise GithubException.GithubException(
             status=response.status_code,
-            data=response_text
+            data=response.text
         )
