@@ -63,8 +63,6 @@ class ExposeAllAttributes(Framework.TestCase):
         pullRequestPart = pullRequest.base
         file = pullRequest.get_files()[0]
         commitComment = repository.get_comment(3630301)
-        status = self.g.get_api_status()
-        statusMessage = self.g.get_last_api_status_message()
         rateLimit = self.g.get_rate_limit()
         hook = repository.get_hooks()[0]
         hookResponse = hook.last_response
@@ -125,8 +123,6 @@ class ExposeAllAttributes(Framework.TestCase):
             rateLimit,
             repository,
             # repositoryKey,  # Security issue if put as-is in ReplayData
-            status,
-            statusMessage,
             # tag,
             team,
             # userKey,  # Security issue if put as-is in ReplayData
