@@ -84,7 +84,7 @@ class Gist(Framework.TestCase):
         gist.edit("Description edited by PyGithub", {"barbaz.txt": github.InputFileContent("File also created by PyGithub")})
         self.assertEqual(gist.description, "Description edited by PyGithub")
         self.assertEqual(gist.updated_at, datetime.datetime(2012, 5, 19, 7, 6, 10))
-        self.assertEqual(set(gist.files.keys()), set(["foobar.txt", "barbaz.txt"]))
+        self.assertEqual(set(gist.files.keys()), {"foobar.txt", "barbaz.txt"})
 
     def testDeleteFile(self):
         gist = self.g.get_gist("5339374")
