@@ -70,6 +70,7 @@ class NamedUser(Framework.TestCase):
         self.assertEqual(self.user.total_private_repos, None)
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/nvie")
+        self.assertEqual(self.user.node_id, "MDQ6VXNlcjgzODQ0")
 
         # test __repr__() based on this attributes
         self.assertEqual(self.user.__repr__(), 'NamedUser(login="nvie")')
@@ -104,6 +105,7 @@ class NamedUser(Framework.TestCase):
         self.assertEqual(self.user.total_private_repos, 5)
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/jacquev6")
+        self.assertEqual(self.user.node_id, "MDQ6VXNlcjMyNzE0Ng==")
 
         # test __repr__() based on this attributes
         self.assertEqual(self.user.__repr__(), 'NamedUser(login="jacquev6")')
